@@ -9,11 +9,11 @@ int
 main(int argc, char **argv)
 {
   GIRepository *repo;
-  GTypelib *ret;
+  GITypelib *ret;
   GIBaseInfo *info;
   char *girdir;
-  GArgument in_arg[1];
-  GArgument ret_arg;
+  GIArgument in_arg[1];
+  GIArgument ret_arg;
   GError *error;
   gboolean invoke_return;
 
